summaryrefslogtreecommitdiffstats
path: root/src/base/ViewElement.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/base/ViewElement.h')
-rw-r--r--src/base/ViewElement.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/base/ViewElement.h b/src/base/ViewElement.h
index 8cc3d09..f898e51 100644
--- a/src/base/ViewElement.h
+++ b/src/base/ViewElement.h
@@ -53,33 +53,33 @@ public:
/**
* Returns the X coordinate of the element, as computed by the
* layout. This is not the coordinate of the associated canvas
* item.
*
* @see getCanvasX()
*/
- virtual double getLayoutX() const { return m_layoutX; }
+ virtual double getLayoutX() const { return m_tqlayoutX; }
/**
* Returns the Y coordinate of the element, as computed by the
* layout. This is not the coordinate of the associated canvas
* item.
*
* @see getCanvasY()
*/
- virtual double getLayoutY() const { return m_layoutY; }
+ virtual double getLayoutY() const { return m_tqlayoutY; }
/**
* Sets the X coordinate which was computed by the layout engine
* @see getLayoutX()
*/
- virtual void setLayoutX(double x) { m_layoutX = x; }
+ virtual void setLayoutX(double x) { m_tqlayoutX = x; }
/**
* Sets the Y coordinate which was computed by the layout engine
* @see getLayoutY()
*/
- virtual void setLayoutY(double y) { m_layoutY = y; }
+ virtual void setLayoutY(double y) { m_tqlayoutY = y; }
void dump(std::ostream&) const;
@@ -88,8 +88,8 @@ public:
protected:
ViewElement(Event *);
- double m_layoutX;
- double m_layoutY;
+ double m_tqlayoutX;
+ double m_tqlayoutY;
Event *m_event;
};
@@ -53,33 +53,33 @@ public:
/**
* Returns the X coordinate of the element, as computed by the
- * layout. This is not the coordinate of the associated canvas
+ * tqlayout. This is not the coordinate of the associated canvas
* item.
*
@@ -53,33 +53,33 @@ public:
/**
* Returns the Y coordinate of the element, as computed by the
- * layout. This is not the coordinate of the associated canvas
+ * tqlayout. This is not the coordinate of the associated canvas
* item.
*
@@ -53,33 +53,33 @@ public:
/**
- * Sets the X coordinate which was computed by the layout engine
+ * Sets the X coordinate which was computed by the tqlayout engine
* @see getLayoutX()
*/
@@ -53,33 +53,33 @@ public:
/**
- * Sets the Y coordinate which was computed by the layout engine
+ * Sets the Y coordinate which was computed by the tqlayout engine
* @see getLayoutY()
*/